%% vmGain(sub, mc, pc), vHands(sub, pc11, mc, tr40), vCurss(sub, pc11, mc, tr40)

% vmGain: visuomotor gain for each subject x condition x perturbation
% location interaction

% vHands, vCurss: hand and cursor velocities at times of perturbation.
% These are not mean values, but individual values for each of the 40
% repetitions.

% load('Fig4.mat')
% or run QG_initialise.m

lw=2; %axis line width
plw=3; %plot line widt
blw=6; %baseline line width
fs = 16; %font size

clm=colormap('lines');
clm(2,:)=clm(5,:);
clm(5,:)=[150,150,150]/255;
close all
velHnd=mean(vHands, 4);
velCrs=mean(vCurss, 4);
velHnd=permute(velHnd, [1,3,2]);
velCrs=permute(velCrs, [1,3,2]);
% averaging velocities in leftward perturbations with respective rightward
% perturbations
for pc=2:2:10
    velHnd(:,:,pc/2)=(velHnd(:,:,pc)+velHnd(:,:,pc+1))/2;
    velCrs(:,:,pc/2)=(velCrs(:,:,pc)+velCrs(:,:,pc+1))/2;
end
velHnd= velHnd(:,:,1:5)/100;
velCrs= velCrs(:,:,1:5)/100;

%% Figure 4A: gains vs hand velocities plot
figure(1)

for mc=5
    xV=velHnd(:,mc,:);
    yG=vmGain(:,mc,:);
    errorbar(squeeze(mean(xV)), squeeze(mean(yG)), squeeze(std(yG))./sqrt(length(yG)), 'linewidth', blw, 'color', clm(mc,:))
    hold on
end
for mc=1:4
    xV=velHnd(:,mc,:);
    yG=vmGain(:,mc,:);
    errorbar(squeeze(mean(xV)), squeeze(mean(yG)), squeeze(std(yG))./sqrt(length(yG)), 'linewidth', plw, 'color', clm(mc,:))
    hold on
end

ylim([0, 2])
yticks([0, 0.5, 1, 1.5, 2])
yticklabels([{'0'}; {''}; {''}; {''}; {'2'}])
ylabel('gain [N]')

xticks(0:0.1:0.6)
xlim([0, 0.6])
xticklabels([{'0'}; {''}; {''}; {'0.3'}; {''}; {''}; {'0.6'}])
box off
% offsetAxes
set(gca, 'FontSize', fs, 'TickDir','out', 'LineWidth', lw)

%% Bootstrapping to fit for slope

for mc=1:5
    xV=velHnd(:,mc,:);
    yG=vmGain(:,mc,:);
    xV=reshape(xV, 50, 1); % Hand velocity vector
    yG=reshape(yG, 50, 1); % Gain vector
    for bs=1:10000
        inds=1+floor(rand(size(xV))*length(xV));
        xVbs=xV(inds);
        yGbs=yG(inds);
        handSlope=@(k) findSlope(k, xVbs, yGbs);    
        slope(mc, bs)=fminsearch(handSlope, 1); %fitting the slope
    end
end
%%  Figure 4C
figure (2)
slope=sort(slope, 2);

% calculate confidence interval bands
slopeEB(:,1) = -slope(:,0.025*bs)+mean(slope, 2);
slopeEB(:,2) = slope(:, 0.975*bs)-mean(slope, 2);

xBar=[0,1,2,3.5,4.5,6];

% plot below

b=bar(xBar, [NaN; mean(slope, 2)],'FaceColor', 'flat', 'linewidth', 1.5);
hold on
errorbar(xBar, [NaN; mean(slope, 2)], [NaN;slopeEB(:,1)], [NaN;slopeEB(:,2)], '.k', 'linewidth', 1.5)
text((xBar(2)+xBar(3))/2, 3.8, 'matched-cursor', 'HorizontalAlignment','center', 'Fontsize', 16)
text((xBar(4)+xBar(5))/2, 3.8, 'matched-hand', 'HorizontalAlignment','center', 'Fontsize', 16)

b.CData=clm([1,1,2,3,4,5], :);
yLim=get(gca, 'YLim');
plot([(xBar(3)+xBar(4))/2, (xBar(3)+xBar(4))/2], [0, 4], 'k--', 'linewidth', 1.5)
plot([(xBar(5)+xBar(6))/2, (xBar(5)+xBar(6))/2], [0, 4], 'k--', 'linewidth', 1.5)
ylim([0, 4])
yticks([0, 1, 2, 3, 4])
ylabel('slope [Ns/m]')

xticks(xBar)
xticklabels([{''};{'late-peak'}; {'early-peak'}; {'early-peak'}; {'late-peak'}; {'baseline'}])
xtickangle(30)
set(gca, 'FontSize', fs, 'TickDir','out', 'LineWidth', lw)
box off
% offsetX
XL=xlim;
XL(1)=-0.35;
xlim(XL)
b(1).BaseLine.LineStyle='none';

%% for cursor: Figure 4B
figure(3)
for mc=5
    xV=velCrs(:,mc,:);
    yG=vmGain(:,mc,:);
    errorbar(squeeze(mean(xV)), squeeze(mean(yG)), squeeze(std(yG))./sqrt(length(yG)), 'linewidth', blw, 'color', clm(mc,:))
    hold on
end
for mc=1:4
    xV=velCrs(:,mc,:);
    yG=vmGain(:,mc,:);
    errorbar(squeeze(mean(xV)), squeeze(mean(yG)), squeeze(std(yG))./sqrt(length(yG)), 'linewidth', plw, 'color', clm(mc,:))
    hold on
end
ylim([0, 2])
yticks([0, 0.5, 1, 1.5, 2])
yticklabels([{'0'}; {' '}; {''}; {' '}; {'2'}])
ylabel('gain [N]')

xticks(0:0.1:0.6)
xlim([0, 0.6])
xticklabels([{'0'}; {''}; {''}; {'0.3'}; {''}; {''}; {'0.6'}])
set(gca, 'FontSize', fs, 'TickDir','out', 'LineWidth', lw)
box off
% offsetAxes

%% Bootstrapping for cursor velocity - gain relationship
for mc=1:5
    xV=velCrs(:,mc,:);
    yG=vmGain(:,mc,:);
    xV=reshape(xV, 50, 1);
    yG=reshape(yG, 50, 1);
    for bs=1:10000
        inds=1+floor(rand(size(xV))*length(xV));
        xVbs=xV(inds);
        yGbs=yG(inds);
        handSlope=@(k) findSlope(k, xVbs, yGbs);
        slope(mc, bs)=fminsearch(handSlope, 1);
    end
end
%%  Figure 4D
figure(4)
slope=sort(slope, 2);
slopeEB(:,1) = -slope(:,0.025*bs)+mean(slope, 2);
slopeEB(:,2) = slope(:, 0.975*bs)-mean(slope, 2);

xBar=[0,1,2,3.5,4.5,6];

b=bar(xBar, [NaN; mean(slope, 2)],'FaceColor', 'flat', 'linewidth', 1.5);
hold on
errorbar(xBar, [NaN; mean(slope, 2)], [NaN;slopeEB(:,1)], [NaN;slopeEB(:,2)], '.k', 'linewidth', 1.5)
text((xBar(2)+xBar(3))/2, 3.8, 'matched-cursor', 'HorizontalAlignment','center', 'Fontsize', 16)
text((xBar(4)+xBar(5))/2, 3.8, 'matched-hand', 'HorizontalAlignment','center', 'Fontsize', 16)

b.CData=clm([1,1,2,3,4,5], :);
yLim=get(gca, 'YLim');
plot([(xBar(3)+xBar(4))/2, (xBar(3)+xBar(4))/2], [0, 4], 'k--', 'linewidth', 1.5)
plot([(xBar(5)+xBar(6))/2, (xBar(5)+xBar(6))/2], [0, 4], 'k--', 'linewidth', 1.5)
ylim([0, 4])
yticks([0, 1, 2, 3, 4])
ylabel('slope [Ns/m]')

xticks(xBar)
xticklabels([{''};{'late-peak'}; {'early-peak'}; {'early-peak'}; {'late-peak'}; {'baseline'}])
xtickangle(30)
set(gca, 'FontSize', fs, 'TickDir','out', 'LineWidth', lw)
box off
% offsetX
XL=xlim;
XL(1)=-0.35;
xlim(XL)
b(1).BaseLine.LineStyle='none';
