% =========================================================================
% Either load the data for the figure from the exported file and leave the
% computations below commented...

load('Fig5.mat')
% posXall, posYall : (sub x movement condition x perturbation location x time series)
% mean X and Y trajectories for each type of trial for each participant.

% =========================================================================


% =========================================================================
% ... or uncomment the computations below (you will need a full data set
% from QG_eLife.mat

% subs=1:10;
% mcs=[1,2,5];
% for sub=subs
%     for mc=mcs
%         TrDat = TrialData(mc, sub);
%         FrDat = FrameData(mc, sub);
%         
%         Trials  = (TrDat.TrialNumber(TrDat.PertCond==12));
%         posXN = nanmean(FrDat.PX(Trials, :));
%         for pc=13:2:22
%             Trials  = TrDat.TrialNumber(TrDat.PertCond==pc);
%             Trials1  = TrDat.TrialNumber(TrDat.PertCond==pc+1);
%             posX = FrDat.PX(Trials, :);
%             posX1 = FrDat.PX(Trials1, :);
%             posXall(sub, mc, (pc-11)/2, :)=(nanmean(posX)-nanmean(posX1))/2;
% 
%             posY = FrDat.PY(Trials, :);
%             posY1 = FrDat.PY(Trials1, :);
%             posYall(sub, mc, (pc-11)/2, :)=nanmean([posY; posY1]);
% 
%         end
%     end
% end

% =========================================================================


%% Figure 4 A

%initialise colormaps
clm=colormap('lines');
clm(2,:)=clm(5,:);
clm(5,:)=[0.8,0.8,0.8];

bx=0;       %subplot index for plotting

for mc=[1, 2, 5]
    clm1=clm(mc, :);
    bx=bx+1;
    
    % calculate mean trajectories
    posX=squeeze(nanmean(posXall,1));   
    posY=squeeze(nanmean(posYall,1));
    
    % convert trajectories from vBOT coordinate space to [% distance]
    yShape=4*(nanmean(squeeze(posY(mc, :,:)))+17.5);    % Y coordinate
    pD=100/6*[1,2,3,4,5];                         % perturbation locations
    for pc=1:5
        % find average perturbation onset times at each onset location
        pertTimes(pc)=find(yShape>pD(pc), 1, 'first');
    end

    % calculate distances to targets for individual participants
    disttots=sqrt((2-squeeze(posXall(:, mc, :,:))).^2 + (25-(squeeze(posYall(:, mc, :,:))+17.5)).^2);
    for sub=1:10
        for pc=1:5
            %find perturbation onset times for individual participants
            pT=find(4*(squeeze(posYall(sub, mc, pc, :))+17.5) > pD(pc), 1);
            % calculate distances to target at the time of perturbation for
            % individual participants
            distToTarget(sub, mc, pc) = squeeze(disttots(sub, pc, pT))-squeeze(25-(posYall(sub, mc, pc, pT)+17.5));
        end
    end
    
    figure(1)
    subplot(1,3,bx)
    for i=1:5
        clm2=(clm1/((i-0.1).^.6)); % adjusting color shade
        % in Y, converting from vBot coordinates (start position at -17.5, 25 cm movement)
        % to [% distance] coordinates
        plot(squeeze(posX(mc, i,:))', (squeeze(posY(mc, i,:))'+17.5)*4, 'Color', clm2, 'linewidth', 2)
        hold on
    end
    
    xlimit=get(gca, 'XLim');
    % ploting perturbation onsets
    for pc=1:5
        plot([-2, +2], [pD(pc),pD(pc)], 'k--', 'linewidth', 2)
    end
    hold off
    
    ylim([0, 100])
    yticks([])
    xticks([-2, 0, 2])

    set(gca, 'LineWidth', 2, 'Fontsize', 16)
    box off
    
    if bx==1
        ylabel('distance (%)')
        yticks([0, 100])
    elseif bx == 2
        xlabel('distance (cm)')    
    end
    
end



%% Figure 4B
clm=colormap('lines');
clm=clm([1,2,5], :);

clm(2,:)=clm(3,:);
clm(3,:)=[0.8,0.8,0.8];

barvals=squeeze(squeeze(nanmean(distToTarget(:, [1,2,5], :))));
barse=squeeze(nanstd(squeeze(distToTarget(:, [1,2,5], :))))./sqrt(10);

figure(2)
b=bar(barvals, 'FaceColor', 'flat', 'linewidth', 2);
hold on

% formatting below
nbars=5;
ngroups=3;

groupwidth = min(0.8, nbars/(nbars + 1.5));

for i = 1:nbars
    % Calculate center of each bar
    x = (1:ngroups) - groupwidth/2 + (2*i-1) * groupwidth / (2*nbars);
    errorbar(x, barvals(:,i), barse(:,i), '.k', 'linewidth', 1.5)
end

for i=1:5
b(i).CData=(clm/((i-0.1).^.6));
end

ylim([0, 0.5])
yticks([0, 0.25, 0.5])

xticks([1,2,3])
xticklabels([{'late-peak'}; {'early-peak'}; {'baseline'}])
set(gca, 'LineWidth', 2, 'Fontsize', 16)
box off
ylabel('distance increase (cm)')

