% =========================================================================
% Either load the data for the figure from the exported file and leave the
% computations below commented...

clear all
load('Fig6.mat')

% data inside the file:
%
% mvTime(sub, mc_hand, pl, trial) - individual movement times for each
% participant, condition, perturbation location, and individual trial.
% mc_hand: 1 - matched cursor late peak, 2 - matched cursor early peak, 3 - baseline
% pl - perturbation location. Odd numbers are different perturbation onset
% locations. For each even number, the onset location is the same as pl -
% 1, but the direction of the cursor jump is opposite.
%
% pTime - respectively to mvTime, the perturbation onset times
%
% mvNeut - same as mvTime, but the non-perturbed condition only (so only
% one pl)
%
% all data is from maintained perturbation trials
% =========================================================================


% =========================================================================
% ... or uncomment the computations below (you will need a full data set
% from QG_eLife.mat


% for sub=1:10
%     for mc=[1,2,5]
%         for pc=13:22
%             
%             trs=FrameData(mc, sub).PY(TrialData(mc, sub).PertCond==pc, :);
%             for k=1:40
%                 ind=find(trs(k, :)>6.8, 1);
%                 trs(k, ind:end) =NaN;
%                 
%             end
%             mvTime(sub, round((mc+1)/2), pc-12, :) = TrialData(mc, sub).TrDur(TrialData(mc, sub).PertCond==pc); %sum(~isnan(trs)')/1000;%sum(~isnan(FrameData(mc, sub).PY(TrialData(mc, sub).PertCond==pc, :))')/1000;%
%             pTime(sub, round((mc+1)/2), pc-12, :) = TrialData(mc, sub).PertTime(TrialData(mc, sub).PertCond==pc);
%         end
%         mvNeut(sub, round((mc+1)/2), :) = TrialData(mc, sub).TrDur(TrialData(mc, sub).PertCond==12);
%     end
% end

% =========================================================================


% get mean data for the respective variables 
mvNeutMean=mean(mvNeut, 3);
mvTimeMean=mean(mvTime, 4);
pTimeMean=mean(pTime, 4);

% combine left and right
mvTimeMeanLR=(mvTimeMean(:,:,[1,3,5,7,9])+mvTimeMean(:,:,[1,3,5,7,9]+1))/2;
pTimeMeanLR=(pTimeMean(:,:,[1,3,5,7,9])+pTimeMean(:,:,[1,3,5,7,9]+1))/2;


%% Figure 5A
clm=colormap('lines');
clm=clm([1,5,5], :);
clm(3,:)=[0.8,0.8,0.8];

barvals=squeeze(mean(mvTimeMeanLR));
barse=squeeze(std(mvTimeMeanLR))/sqrt(10);

figure(1)
b=bar(squeeze(mean(mvTimeMeanLR)), 'FaceColor', 'flat', 'linewidth', 2);

% formatting below
hold on
nbars=5;
ngroups=3;

groupwidth = min(0.8, nbars/(nbars + 1.5));

for i = 1:nbars
    % Calculate center of each bar
    x = (1:ngroups) - groupwidth/2 + (2*i-1) * groupwidth / (2*nbars);
    errorbar(x, barvals(:,i), barse(:,i), '.k', 'linewidth', 1.5)
end
se=std(mvNeutMean(:,1))/sqrt(10);
plot([0.5,1.5], [mean(mvNeutMean(:,1)), mean(mvNeutMean(:,1))], 'k--', 'linewidth', 2)

se=std(mvNeutMean(:,2))/sqrt(10);
plot([1.5,2.5], [mean(mvNeutMean(:,2)), mean(mvNeutMean(:,2))], 'k--', 'linewidth', 2)

se=std(mvNeutMean(:,3))/sqrt(10);
plot([2.5,3.5], [mean(mvNeutMean(:,3)), mean(mvNeutMean(:,3))], 'k--', 'linewidth', 2)


for i=1:5
b(i).CData=(clm/((i-0.1).^.6));
end

ylim([0, 1.5])
yticks([0, 0.5, 1, 1.5])

xticks([0.5,1,2,3])
xticklabels([{' '};{'late-peak'}; {'early-peak'}; {'baseline'}])
set(gca, 'LineWidth', 2, 'Fontsize', 16, 'TickDir', 'out')
box off
% offsetX
ylabel('movement time (s)')
b(1).BaseLine.LineStyle='none';
%% Figure 5B
clm=colormap('lines');
clm=clm([1,5,5], :);
clm(3,:)=[0.8,0.8,0.8];

barvals=squeeze(mean(mvTimeMeanLR-pTimeMeanLR));
barse=squeeze(std(mvTimeMeanLR-pTimeMeanLR))/sqrt(10);

figure(2)
b=bar(barvals, 'FaceColor', 'flat', 'linewidth', 2);
hold on
% formatting below
nbars=5;
ngroups=3;

groupwidth = min(0.8, nbars/(nbars + 1.5));

for i = 1:nbars
    % Calculate center of each bar
    x = (1:ngroups) - groupwidth/2 + (2*i-1) * groupwidth / (2*nbars);
    errorbar(x, barvals(:,i), barse(:,i), '.k', 'linewidth', 1.5)
end

for i=1:5
b(i).CData=(clm/((i-0.1).^.6));
end

barvals=squeeze(mean(repmat(mvNeutMean, 1,1,5)-pTimeMeanLR));
bar(barvals, 'w', 'FaceColor', 'flat', 'linewidth', 2);

ylim([0, 1.5])
yticks([0, 0.5, 1, 1.5])

xticks([0.5,1,2,3])
xticklabels([{' '};{'late-peak'}; {'early-peak'}; {'baseline'}])
set(gca, 'LineWidth', 2, 'Fontsize', 16, 'TickDir', 'out')
box off
% offsetX
ylabel('time to target (s)')
b(1).BaseLine.LineStyle='none';


%%
movT=mean(mvTimeMeanLR,3);

fprintf('Average reching time for baseline: t = %.0f +- %.0f\n', mean(movT(:, 3))*1000, std(movT(:,3)*1000)/sqrt(10));
fprintf('Average reching time for condition 1: t = %.0f +- %.0f\n', mean(movT(:, 1)*1000), std(movT(:,1)*1000)/sqrt(10));
fprintf('Average reching time for condition 2: t = %.0f +- %.0f\n', mean(movT(:, 2)*1000), std(movT(:,2)*1000)/sqrt(10));