clear all
tic
xCost=0.5;
col= get(gca, 'Colororder');
col=[col;col];

% close all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define parameters

% variable parameters
N = [];                 % duration in number of time steps
VMtau=12;               % visuomotor delay. 120ms was used in Liu & Todorov, 2007

prm.c = [0.15, 0.05; -0.05, 0.15];          % control-dependent noise (adjust size by changing the scalar)
prm.r = 0.00001;                               % control signal penalty
Nsim = 40;

prm.dt = 0.01;              % time step (sec) 
prm.m = 1.1;                  % mass of the hand (kg)
prm.b = 7;                 % damping (N/sec)
prm.tau = 0.05;             % time constant (msec)

prm.sigma = 0.015;            % sensory noise
prm.sa = 0.1;                 % relative penalty of final force compared to final velocity

prm.xcost=xCost;            % cost of X-error at the end
prm.ycost=1;                % cost of Y-error at the end
prm.v = 0.2;                 % endpoint velocity penalty (0.1 for hit the target not caring to really stop, 1 for stop at the target-y not caring to hit the target)
prm.f = prm.v/prm.sa;       % endpoint force penalty

Ty = 0.25;                  % target distance
Tx = 0.0;                   % initial target x-coordinate
TxPert=0.02;                % perturbed target x-coordinate

numPertLoc=0:0.01:1;       % locations of cursor jumps
% numPertLoc=[1,2,3,4,5]/6;

t1 = 0.01;                  % beginning of VM window in seconds
t2 = 0.06;                  % end of VM window in seconds

% saving parameters for export
prm.N=N;
prm.VMtau = VMtau;
prm.Nsim = Nsim;

subNo=1;        % How many participants we want to simulate
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Simulating the experiments

fprintf('Simulating baseline condition: \n');
modelNo = 1;
N=94;
pll=0;
%looping over subjects
for sub=1:subNo
    fprintf('Simulating subject %i: ', sub);
    kal_lqg_v2;       
    pll=0;
    fprintf('\n');
end

timeBL=94-time;
fprintf('Simulating condition 1 (late peak) \n');


modelNo = 2;
N=105;
pll=0;
% looping over the subjects
for sub=1:subNo
    fprintf('Simulating subject %i: ', sub);
    kal_lqg_cond1;
    pll=0;
    fprintf('\n');
end

timeC1=105-time;

fprintf('Simulating condition 2 (early peak): \n ');

modelNo = 3;
N=113;
pll=0;
% looping over the subjects
for sub=1:subNo
    fprintf('Simulating subject %i:', sub);
    kal_lqg_cond2;
    pll=0;
    fprintf('\n');
end

timeC2=113-time;

Fig7ABplot;
toc