% Simulation data is necessary before this script can be executed. The data
% can either be obtained via the simulations by running
% Fig8_simulation_wrapper.m (about 10 mins), or by loading a pre-simulated data from
% Fig8_DATA.mat in utils/figure_data/


col = summer(8);
% switching through different peak velocity simulations
for modelNo=1:5
    switch modelNo
        case 1
            cl = '-';
        case 2
            cl = '-.';
        case 3
            cl = ':';
        case 4
            cl='.-';
        case 5
            cl='--';
    end

    figure(3) % velocity vs position plots (Figure 8A)
    plot(squeeze(mean(mean(exportPY{modelNo}, 2),1))'*400, squeeze(mean(mean(exportVY{modelNo}, 2),1))',cl, 'color', col(modelNo, :), 'Linewidth', 2)
    
    hold on


    %% Plotting Force Gains
    [BB,AA]=butter(5,[100/500],'low'); %Butterworth filter
    figure(4) % figure 8B
    hold on
    if subNo > 1
        fbgMeans = mean(squeeze(exportFX{modelNo}( :,:)));
        fbgStds = std(squeeze(exportFX{modelNo}( :,:)))/sqrt(subNo);
        fbgMeans(isnan(fbgMeans))=0;
        temp=filtfilt(BB,AA, fbgMeans);
    else
        fbgMeans = exportFX{modelNo}(:,:);
        temp=filtfilt(BB,AA, fbgMeans);
    end
    plot(rel_pos, temp,cl, 'color', col(modelNo, :), 'Linewidth', 2);
    set(gca, 'Xlim', [0 100], 'Ylim', [0 1.5])
    yticks([0, 0.25, 0.5, 0.75, 1]);
    yticklabels([{0}, {' '}, {' '}, {' '}, {1}]);
    xlabel('location (%)')
    ylabel('correction strength (N)')
    set(gca, 'FontSize', 16, 'FontWeight','bold')
end
figure(3) 
set(gca, 'Xlim', [0 100], 'Ylim', [-inf 1])
yticks([0, 0.25, 0.5, 0.75, 1]);
yticklabels([{0}, {' '}, {' '}, {' '}, {1}]);
xlabel('location (%)')
ylabel('velocity (m/s)')
set(gca, 'FontSize', 16, 'FontWeight','bold')
legend('peak velocity = 80 cm/s', 'peak velocity = 70 cm/s', 'peak velocity = 60 cm/s', 'peak velocity = 50 cm/s', 'peak velocity = 40 cm/s')
box off

%%
figure(6) % figure 8C
plot(-timeV80*10, v80, '-','Color', col(1, :), 'linewidth', 3)
hold on
plot(-timeV70*10, v70,'-.', 'Color', col(2, :), 'linewidth', 3)
plot(-timeV60*10, v60,':', 'Color', col(3, :), 'linewidth', 3)
plot(-timeV50*10, v50,'.-', 'Color', col(4, :), 'linewidth', 3)
plot(-timeV40*10, v40,'--', 'Color', col(5, :), 'linewidth', 3)

xlabel('time to target (ms)')
ylabel('force (N)')
set(gca, 'FontSize', 16, 'FontWeight','bold')
legend('peak velocity = 80 cm/s', 'peak velocity = 70 cm/s', 'peak velocity = 60 cm/s', 'peak velocity = 50 cm/s', 'peak velocity = 40 cm/s')
yticks([0, 0.25, 0.5, 0.75, 1]);
yticklabels([{0}, {' '}, {' '}, {' '}, {1}]);
