% May need to run Fig8ABC.m first 

% BADS is required to run the optimisation. The package is available at
% https://github.com/lacerbi/bads
%
% Reference: 
% Acerbi, L. & Ma, W. J. (2017). Practical Bayesian Optimization for Model 
% Fitting with Bayesian Adaptive Direct Search. 
% In Advances in Neural Information Processing Systems 30, pages 1834-1844.

% initialise optimisation settings
paras= [184963,19.9,1.142,317, 94];

%options.TolFun=1e-7;
LB=paras/1000;
UB=paras*1000;
PLB = LB*10;
PUB =UB/10;

LB(5)=0;
UB(5)=1000;
PLB(5)=0;
PUB(5)=100;


% three movement conditions
% i = 1 : baseline
% i = 2 : late peak
% i = 3 : early peark
for i =[1,2,3]
    % setting the colors for plot and initial condition for optimisation
    % (so it doesn't take to long)
    switch i
        case 1 
            paras= [126959,21.7,1.185,317, 140];
            cl='k';
            cm='k.';
        case 2
            paras= [100650,21.1,1.312,319, 196];
            paras=[9.1127    0.0031    0.0001    0.0372    0.0258]*1e4;
            cl='b';
            cm='b.'
        case 3
            paras= [184963,19.9,1.142,317, 94];
            cl='g';
            cm='g.';
    end
    
    % fitting the tuning function described in the article
    fB=@(paras) fitBestTimeGain(paras, allT{i}, allG{i})
    
    % using BADS (Acerbi & Ma, 2017)
    [bestParas, score] = bads(fB, paras, LB,UB,PLB,PUB)

    figure(1)
    % plotting individual gains from silumation
    plot(-allT{i}, allG{i}, cm);
    hold on
    t=1:1:1400;
    paras=bestParas;
    plot(-t, min(paras(1)./(t-paras(5)).^2, paras(3)./(1+exp(-(t-paras(4))./paras(2)))), cl, 'linewidth', 2)
    switch i
        case 1 
            fBaseline = @(t)  min(paras(1)./(t-paras(5)).^2, paras(3)./(1+exp(-(t-paras(4))./paras(2))));
        case 2
            fCond1 = @(t)  min(paras(1)./(t-paras(5)).^2, paras(3)./(1+exp(-(t-paras(4))./paras(2))));
        case 3
            fCond2 = @(t)  min(paras(1)./(t-paras(5)).^2, paras(3)./(1+exp(-(t-paras(4))./paras(2))));
    end
end
xlabel('time to target (ms)')
ylabel('force (N)')
set(gca, 'FontSize', 16, 'FontWeight','bold')
h = findobj(gca,'Type','line');
legend([h(1), h(3), h(5)], {'early-peak', 'late-peak', 'baseline'})
