
xCost=0.5;
col= get(gca, 'Colororder');
col=[col;col];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define parameters

% variable parameters
N = [];                 % duration in number of time steps
VMtau=12;               % visuomotor delay. 120ms was used in Liu & Todorov, 2007

% might need changing
prm.c = [0.15, 0.05; -0.05, 0.15];          % control-dependent noise (adjust size by changing the scalar)
prm.r = 0.00001;                              % control signal penalty
Nsim = 40;

% definitely fixed parameters
prm.dt = 0.01;              % time step (sec) 
prm.m = 1.1;                  % mass of the hand (kg)
prm.b = 7;                 % damping (N/sec)
prm.tau = 0.05;             % time constant (msec)

prm.sigma = 0.015;            % sensory noise
prm.sa = 0.1;                 % relative penalty of final force compared to final velocity

prm.xcost=xCost;           % cost of X-error at the end
prm.ycost=1;                % cost of Y-error at the end
prm.v = .2;                 % endpoint velocity penalty (0.1 for hit the target not caring to really stop, 1 for stop at the target-y not caring to hit the target)
prm.f = prm.v/prm.sa;       % endpoint force penalty

Ty = 0.25;                  % target distance
Tx = 0.0;                   % initial target x-coordinate
TxPert=0.02;                % perturbed target x-coordinate

numPertLoc=0:0.01:1;

t1 = 0.01;                  % beginning of VM window in seconds
t2 = 0.06;                  % end of VM window in seconds

% saving parameters for export
prm.N=N;
prm.VMtau = VMtau;
prm.Nsim = Nsim;



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Simulating the experiments

% N are selected via previous optimisation so that the desired peak
% velocity is achieved in the simulation.

fprintf('Simulating Vpeak = 80 cm/s \n');
modelNo = 1;
N=73;
% looping over the subjects
for sub=1:subNo
    fprintf('Subject %i: ', sub);
    switch j
        % j is the condition
        case 1
            kal_lqg_v2; 
        case 2
            kal_lqg_cond1; 
        case 3
            kal_lqg_cond2; 
    end
end
fprintf('\n');
timeV80=73-time;

fprintf('Simulating Vpeak = 70 cm/s \n');
modelNo = 2;
N=85;
pll=0;
%looping over subjects
for sub=1:subNo
    fprintf('Subject %i: ', sub);
    switch j
        case 1
            kal_lqg_v2; 
        case 2
            kal_lqg_cond1; 
        case 3
            kal_lqg_cond2; 
    end
          
    pll=0;
end
timeV70=85-time;

fprintf('Simulating Vpeak = 60 cm/s \n');
modelNo = 3;
N=105;
pll=0;
% looping over the subjects
for sub=1:subNo
    fprintf('Subject %i: ', sub);
    switch j
        case 1
            kal_lqg_v2; 
        case 2
            kal_lqg_cond1; 
        case 3
            kal_lqg_cond2; 
    end
    pll=0;
end
fprintf('\n');
timeV60=105-time;

fprintf('Simulating Vpeak = 50 cm/s \n');
modelNo = 4;
N=113;
pll=0;
% looping over the subjects
for sub=1:subNo
    fprintf('Subject %i: ', sub);
    switch j
        case 1
            kal_lqg_v2; 
        case 2
            kal_lqg_cond1; 
        case 3
            kal_lqg_cond2; 
    end
    pll=0;
end
fprintf('\n');
timeV50=113-time;

fprintf('Simulating Vpeak = 40 cm/s \n');
modelNo = 5;
N=124;
pll=0;
% looping over the subjects
for sub=1:subNo
    fprintf('Subject %i: ', sub);
    switch j
        case 1
            kal_lqg_v2; 
        case 2
            kal_lqg_cond1; 
        case 3
            kal_lqg_cond2; 
    end
    pll=0;
end
fprintf('\n');
timeV40=124-time;
