% this plots the data of the simulations
% 
% just for the figures please import Fig9_DATA.mat, which contains the
% simulation results exported to a file
% 

[BB,AA]=butter(5,[10/500],'low'); %Butterworth filter. Set for 1kHz sampling rate
subNo=1;
% we will filter the simulation data eventually to get the smooth curves.
% The roughness in the simulation data appears from a discrete sampling,
% but with sampling rate above our computational capabilities we expect the
% curves to be smooth.

for modelNo=[1,2,3]
    switch modelNo
        case 1
            cl = 'k';
            N=94;
        case 2
            cl = 'k:';
            N=80;
        case 3
            cl = 'k-.';
            N=75;
        case 4
            cl = 'r';
            N=94;
    end

    
    figure(2)
    
    plot((1:N)*10, squeeze(mean(mean(exportPY{modelNo}(:,:,:), 2),1))', cl, ...
        'linewidth', 2)
    set(gca, 'FontSize', 16, 'FontWeight','bold')
    xlabel('time (ms)')
    ylabel('position (cm)')
    xlim([-Inf,Inf]);
%     ylim([0, 0.8])
%     yticks([0, 0.2, 0.4, 0.6, 0.8])
%     yticklabels([{0},{20},{40},{60},{80}])
    hold on
%     xticks([0, 1, 2, 3, 4, 5]/20)
%     xticklabels([{0},{20},{40},{60},{80},{100}])
    box off
    
    % ploting position-velocity curve (Figure 9A)
    figure(3)
    
    % velocity profiles in Y direction are the same, independent on
    % perturbation onset. Average across perturbation locations to get
    % profiles
    plot(squeeze(mean(mean(exportPY{modelNo}(:,:,:), 2),1))', squeeze(mean(mean(exportVY{modelNo}(:,:,:),2),1))', cl, ...
        'linewidth', 2)
    set(gca, 'FontSize', 16, 'FontWeight','bold')
    xlabel('location (%)')
    ylabel('velocity (cm/s)')
    xlim([-Inf,Inf]);
    ylim([0, 0.8])
    yticks([0, 0.2, 0.4, 0.6, 0.8])
    yticklabels([{0},{20},{40},{60},{80}])
    hold on
    xticks([0, 1, 2, 3, 4, 5]/20)
    xticklabels([{0},{20},{40},{60},{80},{100}])
    box off
    
    % Plotting gains vs position (Figure 9B)
    figure(4)
    hold on
    if subNo > 1 
        % if we simulated more than one participant, average across
        % simulated participants and calculate standard errors
        fbgMeans = mean(squeeze(exportFX{modelNo}(:,:)));
        fbgStds = std(squeeze(exportFX{modelNo}(:,:)))/sqrt(subNo);
        % filter
        temp=spline(rel_pos, fbgMeans, 0:1:100);
        plot(rel_pos, fbgMeans, cl, 'Linewidth', 2)
    else
        % if we simulated one participant:
        fbgMeans = exportFX{modelNo};
        % set NaNs to zero
        fbgMeans(isnan(fbgMeans))=0;
        % filter
%         temp=filtfilt(BB,AA, fbgMeans);
        temp=fbgMeans;
        plot(rel_pos, temp, cl, 'Linewidth', 2);
    end
    set(gca, 'Xlim', [0 100], 'Ylim', [-inf 1.5])
    xlabel('location (%)')
    ylabel('correction strength (N)')
    xticks([0, 1, 2, 3, 4, 5]*20)
    xticklabels([{0},{20},{40},{60},{80},{100}])
    yticks([0, 0.4, 0.8, 1.2, 1.6])
    yticklabels([{0},{' '},{' '},{' '}, {1.6}])
    set(gca, 'FontSize', 16, 'FontWeight','bold')
    ylim([0, 1.6])
    
    % Plotting gains vs time-to-target (Figure 9C)
    figure(5)
    hold on
    if subNo > 1 
        % if we simulated more than one participant, average across
        % simulated participants and calculate standard errors
        fbgMeans = mean(squeeze(exportFX{modelNo}(:,:)));
        fbgStds = std(squeeze(exportFX{modelNo}(:,:)))/sqrt(subNo);
        % filter
        temp=spline(rel_pos, fbgMeans, 0:1:100);
        plot(rel_pos, fbgMeans, cl, 'Linewidth', 2)
    else
        % if we simulated one participant:
        fbgMeans = exportFX{modelNo};
        t=timesStored{modelNo};
        % set NaNs to zero
        fbgMeans(isnan(fbgMeans))=0;
        % filter
%         temp=filtfilt(BB,AA, fbgMeans);
        temp=fbgMeans;
        plot(t*10, temp, cl, 'Linewidth', 2);
    end
    set(gca, 'Ylim', [-inf 1.5], 'XDir', 'reverse')
    xlabel('time (ms)')
    ylabel('correction strength (N)')
%     xticks([0, 1, 2, 3, 4, 5]*20)
%     xticklabels([{0},{20},{40},{60},{80},{100}])
    yticks([0, 0.4, 0.8, 1.2, 1.6])
    yticklabels([{0},{' '},{' '},{' '}, {1.6}])
    set(gca, 'FontSize', 16, 'FontWeight','bold')
    ylim([0, 1.6])
end
