
% clear all

col= get(gca, 'Colororder');
col=[col;col];

% close all
model='r';
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% define parameters

% variable parameters
N = 50;                 % duration in number of time steps
VMtau=12;               % visuomotor delay. 120ms was used in Liu & Todorov, 2007

prm.c = [0.15, 0.05; -0.05, 0.15];          % control-dependent noise (adjust size by changing the scalar)
prm.r = 0.000003; %0.00001;                              % control signal penalty
qScale=5;
Nsim = 40;

prm.dt = 0.01;              % time step (sec) 
prm.m = 1.1;                  % mass of the hand (kg)
prm.b = 7;                 % damping (N/sec)
prm.tau = 0.05;             % time constant (msec)

prm.sigma = 0.015;            % sensory noise
prm.sa = 0.1;                 % relative penalty of final force compared to final velocity

prm.xcost=1;            % cost of X-error at the end
prm.ycost=1;                % cost of Y-error at the end
prm.v = 0.1;                 % endpoint velocity penalty (0.1 for hit the target not caring to really stop, 1 for stop at the target-y not caring to hit the target)
prm.f = prm.v/prm.sa;       % endpoint force penalty

Ty = 0.25;                  % target distance
Tx = 0.0;                   % initial target x-coordinate
TxPert=0.02;                % perturbed target x-coordinate

pOnsDs=[1,2,3,4,5]/6;%0:0.001:1;       % locations of cursor jumps

t1 = 0.01;                  % beginning of VM window in seconds
t2 = 0.06;                  % end of VM window in seconds

% saving parameters for export
prm.N=N;
prm.VMtau = VMtau;
prm.Nsim = Nsim;

initialiseSSM
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Simulating the experiments

[K,L,Cost] = receding_lqg( A,B, H, 0, D0.^D0, Qt,R, X1,0, Nsim, 1, 15, C);

pt=0;
for pOnsD = pOnsDs
    Xa = zeros(size(A,1),N);
    Xa(:,1) = X1;
    pt=pt+1;
    k=1;
    firstTime=1;
    TargDist = 0.25;
    while TargDist > 0.004
        u = -L(:,:,1)*Xa(:,k);
        Xa(:,k+1) = A*Xa(:,k) + B*u;

        if Xa(2,k+1) > pOnsD*Ty
            if firstTime
                
                firstTime=0;
                pOnsT=k+1;
            end
            if k >= pOnsT+VMtau
                Xa(7,k+1) = TxPert; 
            end
        end
        
        k=k+1;
        TargDist = norm(Xa(7:8, k)-Xa(1:2, k));
    end
    fprintf("Pert @ k=%d, duration=%d, ttt=%d\n", pOnsT, k, k-pOnsT)
    dur_rec(pt)=k/100;
    
    gain_rec(pt) = mean(Xa(5, (pOnsT+VMtau+1):(pOnsT+VMtau+6)));
end

vel{2}=Xa(4,:);
pos{2}=Xa(2,:);
