%============================================
%DEFAULT SETTINGS (FIXED) BELOW
%============================================
clearvars -except FrameData TrialData FrDat TrDat SubData X Y X1 Y1 SE SE1

%for figure formating
set(0,'DefaultAxesLayer','top')
col=get(gca, 'colororder');
col = cat(1, col, col./2);
marker='.*^sphdvvvvvvv';
msize=[24,8,8,8,8,8,8,8,8,8,8,8,8];
close all

% Perturbation conditions (1-11 are in the channel; 12-22 in the null field):
% 1 - neutral reach (no cursor jump)
% [2,4,6,8,10] - cursor jumps at different onset locations (2 - furthest,
% 10 - closest to the target)
% [3,5,7,9,11] - matching above respectively, just different direction of the jump
% We only analyse channel trials here
pertconds=[1,2,3,4,5,6,7,8,9,10,11]';

% Movement conditions:
% 1 - Matched-cursor late-peak (blue)
% 2 - Matched-cursor early-peak (green)
% 3 - Matched-hand early-peak (yellow)
% 4 - Mathced-hand late-peak (purple)
% 5 - Baseline (grey)
movconds=[1,2,3,4,5]';

%============================================
%LOAD SUBJECT DATA IF NOT YET LOADED
%============================================
if ~(exist('FrameData', 'var') && exist('TrialData', 'var'))
    load('TTT_subdata.mat')
end

%============================================
% LOOP OVER SUBJECTS
%============================================
for sub=1:10
    % loop over conditions
    for mc=1:5
        % extract current experiment
        TrDat=TrialData(mc,sub);
        FrDat=FrameData(mc,sub);
        
        % Subtract neutral
        FX=zeros(11, 2000);
       
        neutralFX=mean(FrDat.FTX(TrDat.PertCond==1, :), 1);
%         for pc=1:11
%           %  FX(pc,:)=(mean(FrDat.FTX(TrDat.PertCond==pc & TrDat.PeakDH >=0.43 & TrDat.PeakDH <= 0.57 & TrDat.PeakSpeed >= 35 & TrDat.PeakSpeed <= 65, :), 1)-neutralFX)';
%             VY(pc,:,:)=((FrDat.VY(TrDat.PertCond==pc, :)));
%             PY(pc,:,:)=(FrDat.PY(TrDat.PertCond==pc, :));
%         end
%         for pc=1:11
%             plot(mean(FrDat.VY(TrDat.PertCond==pc, :), 1))
%             hold on
%         end
        % Feedback gains
        fbGain=[];
        
        %get trial numbers for each perturbation type
        for pc=1:22
            pertTrials(pc,:) = TrDat.TrialNumber(TrDat.PertCond==pc);
        end
        
        % loop through trials
        for tr=1:880
            % find the visuomotor feedback window (start and end)
            % we define VM feedback window as [180, 230] ms after
            % perturbation
            vmStart = find(FrDat.TT(tr,:) > TrDat.PertTime(tr)+0.180, 1, 'first');
            vmEnd = find(FrDat.TT(tr,:) > TrDat.PertTime(tr)+0.230, 1, 'first');
            
            % calculate the gain in the current trial
            fbGain(tr) = nanmean(FrDat.FTX(tr, vmStart:vmEnd));
            
            % time to target is movement duration minus perturbation time
            tmTT(tr) = TrDat.TrDur(tr) - TrDat.PertTime(tr);
            
            % extract hand position, velocity and cursor velocity at
            % perturbation onset
            pH(tr) = FrDat.PY(tr, find(FrDat.TT(tr,:) > TrDat.PertTime(tr), 1, 'first'));
            vH(tr) = FrDat.VY(tr, find(FrDat.TT(tr,:) > TrDat.PertTime(tr), 1, 'first'));
            vC(tr) = vH(tr)*FrDat.SpeedGain(tr, find(FrDat.TT(tr,:) > TrDat.PertTime(tr), 1, 'first'));
        end
        
        for pc=2:2:10
            % gain is left minus right (so bias due to biomechanics cancels
            % out), averaged over 40 blocks
            vmGain(sub, mc, pc/2)=nanmean(-fbGain(pertTrials(pc,:))+ fbGain(pertTrials(pc+1,:)));
            
            % average time to target in channel trials (average left and
            % right)
            avTTT(sub, mc, pc/2)=nanmean((tmTT(pertTrials(pc,:))+tmTT(pertTrials(pc+1,:)))/2);
            
            % exporting gains from individual (pairs of) trials
            vmFirst(sub, mc, pc/2, :)=-fbGain(pertTrials(pc,:))+ fbGain(pertTrials(pc+1,:));
        end
        
        % exporting hand position, velocity and cursor velocity for later
        % analysis to save re-running this
        for pc=1:11
            vHands(sub, pc, mc, :) = vH(pertTrials(pc,:));
            pHands(sub, pc, mc, :) = pH(pertTrials(pc,:));
            vCurss(sub, pc, mc, :) = vC(pertTrials(pc,:));
        end
        
        % we export times to target from non-channel trials
        for pc=12:22
            tTTarg(sub, pc-11, mc, :) = tmTT(pertTrials(pc,:));
        end
    end
end

% below we loop through each subject and scale their total responses by 
% their mean in order to reduce participant bias.

for sub=1:10
    vmGain(sub,:,:)=vmGain(sub,:,:)/mean(mean(vmGain(sub,:,:)));
end

%% Check for decay in response (Methods -> ProbeTrials, end)

figure
for i=1:2:39
    temp((i+1)/2)=mean(squeeze(mean(mean(mean(vmFirst(:, :, :, i:(i+1)), 2), 3), 4)));
end

bar(temp)

beg=squeeze(mean(mean(mean(vmFirst(:, :, :, 1:2), 2), 3), 4));
endd=squeeze(mean(mean(mean(vmFirst(:, :, :, 39:40), 2), 3), 4));
fprintf('Initial = %0.3f, final = %0.3f, change = %0.0f perc.\n', mean(beg), mean(endd), (mean(endd)/mean(beg)-1)*100)
