initialiseSSM                   % compute system dynamics and cost matrices


paras = [-4.66602505056400,0.680413124312639,-0.108239652597067];

% ========================
% This simulation condition is also used for plotting figure 8. The switch
% below is required to obtain the right velocity profiles over different
% peak velocities.
switch N
    case 145
        paras = [-1.8, 0.27, -0.46];
    case 124
        paras = [-3.0, 0.54, -0.23];
    case 105
        paras = [-5.6, 0.59, -0.37];
    case 85
        
        paras = [-6.376360093981930,0.700000000000000,0];
    case 73
        paras = [-4.480351330400598,0.626281905810219,-0.223864288181978,73.245530622660740];
        
    case 60
        paras = [-6.029931369703263,0.603120974753983,-0.663743875280488,60];
end
% ====================================
Rscale=exp(paras(1).*linspace(paras(2), paras(3), N)); %
Rscale=Rscale./mean(Rscale);

for k=1:N
    R{k}=R{k}*Rscale(k)*[1,0;0,1];
end     

% pos = positionProfile(A,B,Qf, R, X1, N);    % estimate movement profile with no perturbations
% time = convert_d2t(numPertLoc, pos);        % obtain times for each perturbation


% simulate neutral reaching
[K,L,Cost,Xa,XSim,Xhat,CostSim, Un] = kalman_lqg_pert( A,B, H, 0, ...
        D0.^D0, Qt,R, X1,0, Nsim, 1, 15, C, 50, 0.0, 0);
    
pos=Xa(2,:);
time = convert_d2t(numPertLoc, pos);

neutralF=(mean(squeeze(XSim(5,:,:))));  % calculate neutral (baseline) x-force of reaching in no perturbation

%% simulate everything
for pt=1:length(time)
    Tpert=time(pt)+VMtau;
    
    [K,L,Cost,Xa,XSim,Xhat,CostSim, Un] = kalman_lqg_pert( A,B, H, 0, ...
        D0.^D0, Qt,R, X1,0, Nsim, 1, 15, C, Tpert, TxPert, 0);
    
    simulations{pt} = XSim;
    controlInputs{pt} = Un;
    simulations{pt}(5,:,:) = simulations{pt}(5,:,:)-reshape(neutralF, 1,1,N);
end


%% calculate feedback gains
fbgtime = [t1/prm.dt+VMtau t2/prm.dt+VMtau];
fbgIntervals = ones(length(time),2);
fbgIntervals(1,:) = fbgIntervals(1,:) .* fbgtime(1);
fbgIntervals(2,:) = fbgIntervals(2,:) .* fbgtime(2);
fbgIntervals(:,1) = fbgIntervals(:,1) + fbgtime(1);
fbgIntervals(:,2) = fbgIntervals(:,2) + fbgtime(2);
 
rel_pos = numPertLoc * 100;
 
for i = 1 : length(time)
    fbgIntervals(i,:) = [time(i)+fbgtime(1), time(i)+fbgtime(2)];
end
 
for i = 1 : length(simulations)
    for ii = 1 : Nsim
        if fbgIntervals(i,2) > N
            FbG(ii) = 0;
        else
            FbG(ii) = mean(simulations{i}(5,ii,[fbgIntervals(i,1), fbgIntervals(i,2)]));
        end
    end
    FeedbackGains(i, :) = FbG;
    FbG = [];
end

fbgMeans = mean(FeedbackGains,2);
fbgStds = std(FeedbackGains, [], 2)/sqrt(Nsim);

for pt=1:length(time)
    exportVY{modelNo}(sub, pt, :) = mean(squeeze(simulations{pt}(4,:,:)));
    exportPX{modelNo}(sub, pt, :) = mean(squeeze(simulations{pt}(1,:,:)));
    exportPY{modelNo}(sub, pt, :) = mean(squeeze(simulations{pt}(2,:,:)));
    
end
exportFX{modelNo}(sub, :) = fbgMeans;
